searchData={"items":[{"type":"module","doc":"This module provides AMQP-related types.","title":"AMQP","ref":"AMQP.html"},{"type":"type","doc":"","title":"AMQP.argument_type/0","ref":"AMQP.html#t:argument_type/0"},{"type":"type","doc":"","title":"AMQP.arguments/0","ref":"AMQP.html#t:arguments/0"},{"type":"module","doc":"Provides access to configured connections and channels.","title":"AMQP.Application","ref":"AMQP.Application.html"},{"type":"function","doc":"Provides an easy way to access an AMQP channel.\n\nAMQP.Application provides a wrapper on top of `AMQP.Channel` with .\n\nThe channel will be monitored by AMQP's GenServer and it will automatically\ntry to reopen when the channel is gone.","title":"AMQP.Application.get_channel/1","ref":"AMQP.Application.html#get_channel/1"},{"type":"function","doc":"When you want to have a single channel in your app:\n\n    config :amqp,\n      connection: [url: \"amqp://guest:guest@localhost:15672\"],\n      channel: []\n\nThen the channel will be open at the start of the application and you can\naccess it via this function.\n\n    iex> {:ok, chan} = AMQP.Application.get_channel()\n\nYou can also set up multiple channels with `:channels` key:\n\n    config :amqp,\n      connections: [\n        business_report: [url: \"amqp://host1\"],\n        analytics: [url: \"amqp://host2\"]\n      ],\n      channels: [\n        business_report: [connection: :business_report],\n        analytics: [connection: :analytics]\n      ]\n\nThen you can access each channel with its name.\n\n    iex> {:ok, conn1} = AMQP.Application.get_channel(:business_report)\n    iex> {:ok, conn2} = AMQP.Application.get_channel(:analytics)\n\nYou can also have multiple channels for a single connection.\n\n    config :amqp,\n      connection: [],\n      channels: [\n        consumer: [],\n        producer: []\n      ]","title":"Usage - AMQP.Application.get_channel/1","ref":"AMQP.Application.html#get_channel/1-usage"},{"type":"function","doc":"* `:connection` - The connection name configured with `connection` or\n    `connections` (default `:default`)\n\n  * `:retry_interval` - The retry interval in milliseconds when the channel is\n    failed to open (default `5000`)","title":"Configuration options - AMQP.Application.get_channel/1","ref":"AMQP.Application.html#get_channel/1-configuration-options"},{"type":"function","doc":"Although AMQP will reopen the named channel automatically when it is closed\nfor some reasons, your application still needs to monitor the channel for a\nconsumer process.\n\nBe aware the channel reopened doesn't automatically recover the subscription\nof your consumer\n\nHere is a sample GenServer module that monitors the channel and re-subscribe\nthe channel.\n\n    defmodule AppConsumer do\n      use GenServer\n      @channel :default\n      @queue \"myqueue\"\n\n      ....\n\n      def handle_info(:subscribe, state) do\n        case subscribe() do\n          {:ok, chan} ->\n            {:noreply, Map.put(state, :channel, chan)}\n          _ ->\n            {:noreply, state}\n        end\n      end\n\n      def handle_info({:DOWN, _, :process, pid, reason}, %{channel: %{pid: pid}} = state) do\n        send(self(), :subscribe)\n        {:noreply, Map.put(state, :channel, nil)}\n      end\n\n      defp subscribe() do\n        case AMQP.Application.get_channel(@channel) do\n          {:ok, chan} ->\n            Process.monitor(chan.pid)\n            {:ok, _consumer_tag} = AMQP.Basic.consume(@channel, @queue)\n            {:ok, chan}\n\n          _error ->\n            Process.send_after(self(), :subscribe, 1000)\n            {:error, :retrying}\n        end\n      end\n    end","title":"Caveat - AMQP.Application.get_channel/1","ref":"AMQP.Application.html#get_channel/1-caveat"},{"type":"function","doc":"Provides an easy way to access an AMQP connection.\n\nThe connection will be monitored by AMQP's GenServer and it will\nautomatically try to reconnect when the connection is gone.","title":"AMQP.Application.get_connection/1","ref":"AMQP.Application.html#get_connection/1"},{"type":"function","doc":"When you want to have a single connection in your app:\n\n    config :amqp, connection: [\n        url: \"amqp://guest:guest@localhost:15672\"\n      ]\n\nYou can also use any options available on `AMQP.Connection.open/2`:\n\n    config :amqp, connection: [\n        host: \"localhost\",\n        port: 15672\n        username: \"guest\",\n        password: \"guest\"\n      ]\n\nThen the connection will be open at the start of the application and you can\naccess via this function.\n\n    iex> {:ok, conn} = AMQP.Application.get_connection()\n\nBy default, it tries to connect to your local RabbitMQ. You can simply pass\nthe empty keyword list too:\n\n    config :amqp, connection: [] # == [url: \"amqp://0.0.0.0\"]\n\nYou can set up multiple connections with `:connections` key:\n\n    config :amqp, connections: [\n        business_report: [\n          url: \"amqp://host1\"\n        ],\n        analytics: [\n          url: \"amqp://host2\"\n        ]\n      ]\n\nThen you can access each connection with its name.\n\n    iex> {:ok, conn1} = AMQP.Application.get_connection(:business_report)\n    iex> {:ok, conn2} = AMQP.Application.get_connection(:analytics)\n\nThe default name is :default so These two configurations are equivalent:\n\n    config :amqp, connection: []\n    config :amqp, connections: [default: []]","title":"Usage - AMQP.Application.get_connection/1","ref":"AMQP.Application.html#get_connection/1-usage"},{"type":"function","doc":"* `:retry_interval` - The retry interval in milliseconds when the connection\n    is failed to open. (default `5000`)\n\n  * `:url` - AMQP URI for the connection\n\nSee also `AMQP.Connection.open/2` for all available options.","title":"Configuration options - AMQP.Application.get_connection/1","ref":"AMQP.Application.html#get_connection/1-configuration-options"},{"type":"module","doc":"Functions to publish, consume and acknowledge messages.","title":"AMQP.Basic","ref":"AMQP.Basic.html"},{"type":"function","doc":"Acknowledges one or more messages.","title":"AMQP.Basic.ack/3","ref":"AMQP.Basic.html#ack/3"},{"type":"function","doc":"* `:multiple` - If set, all messages up to the one specified by `delivery_tag`\n    are acknowledged (default `false`)","title":"Options - AMQP.Basic.ack/3","ref":"AMQP.Basic.html#ack/3-options"},{"type":"function","doc":"Stops the given consumer from consuming.\n\nThis method cancels a consumer. This does not affect already delivered\nmessages, but it does mean the server will not send any more messages for\nthat consumer. The client may receive an arbitrary number of messages in\nbetween sending the cancel method and receiving the reply.\n\n`consumer_tag` identifies the \"subscription\" to cancel, that is, the\nsubscription of a consumer to a specific queue. The consumer tag is returned\nby `consume/4`.","title":"AMQP.Basic.cancel/3","ref":"AMQP.Basic.html#cancel/3"},{"type":"function","doc":"* `:nowait` - If set, the cancel operation is asynchronous (default\n    `false`)","title":"Options - AMQP.Basic.cancel/3","ref":"AMQP.Basic.html#cancel/3-options"},{"type":"function","doc":"Removes the return handler, if it exists. Does nothing if there is no\nsuch handler.","title":"AMQP.Basic.cancel_return/1","ref":"AMQP.Basic.html#cancel_return/1"},{"type":"function","doc":"Registers a queue consumer process. The `pid` of the process can be set using\nthe `consumer_pid` argument and defaults to the calling process.\n\nThe consumer process will receive the following data structures:\n\n  * `{:basic_deliver, payload, meta}` - This is sent for each message\n    consumed, where `payload` contains the message content and `meta`\n    contains all the metadata set when sending with `AMQP.Basic.publish/5` or\n    additional info set by the broker\n\n  * `{:basic_consume_ok, %{consumer_tag: consumer_tag}}` - Sent when the\n    consumer process is registered with Basic.consume. The caller receives\n    the same information as the return of `AMQP.Basic.consume/4`\n\n  * `{:basic_cancel, %{consumer_tag: consumer_tag, nowait: nowait}}` - Sent\n    by the broker when the consumer is unexpectedly cancelled (such as after a\n    queue deletion)\n\n  * `{:basic_cancel_ok, %{consumer_tag: consumer_tag}}` - Sent to the\n    consumer process after a call to `AMQP.Basic.cancel/3`","title":"AMQP.Basic.consume/4","ref":"AMQP.Basic.html#consume/4"},{"type":"function","doc":"* `:consumer_tag` - Specifies the consumer tag for this consumer (as a\n    string).  This tag is local to the given channel `chan`, so different\n    channels can have consumers that use the same consumer tag. If the given\n    consumer tag is `\"\"`, then the server autogenerates the tag (default `\"\"`)\n\n  * `:no_local` - If set, the server won't send messages to the connection\n    that published them (default `false`)\n\n  * `:no_ack` - If set, the server will not expect message acks from the\n    consumer and will consider every message that it believes was delivered to\n    the consumer as acknowledged. Defaults to `false`, meaning that messages\n    need to be acked explicitly through `ack/3`\n\n  * `:exclusive` - If set, requests exclusive consumer access, meaning that\n    only this consumer can consume from the given `queue`. Note that the client\n    cannot have exclusive access to a queue that already has consumers\n\n  * `:nowait` - If set, the consume operation is asynchronous (default\n    `false`)\n\n  * `:arguments` - A list of arguments to pass when consuming\n    (of type `t:AMQP.arguments/0`). See the [README](readme.html)\n    for more information (default `[]`)","title":"Options - AMQP.Basic.consume/4","ref":"AMQP.Basic.html#consume/4-options"},{"type":"function","doc":"Polls a queue for an existing message.\n\nReturns the tuple `{:empty, meta}` if the queue is empty or the tuple `{:ok,\npayload, meta}` if at least one message exists in the queue. The returned\n`meta` map includes the entry `:message_count` with the current number of\nmessages in the queue.\n\nReceiving messages by polling a queue is not as as efficient as subscribing a\nconsumer to a queue, so consideration should be taken when receiving large\nvolumes of messages.","title":"AMQP.Basic.get/3","ref":"AMQP.Basic.html#get/3"},{"type":"function","doc":"* `:no_ack` - If set, the broker is told that the received will not send an\n    acknoledgement of the message. Once the broker believes it has delivered\n    the message, then it's free to assume that the consuming application has\n    taken responsibility for it. In general, a lot of applications will not\n    want these semantics, rather, they will want to explicitly acknowledge the\n    receipt of a message (through `ack/3`) (default `false`, meaning\n    explicit acks)","title":"Options - AMQP.Basic.get/3","ref":"AMQP.Basic.html#get/3-options"},{"type":"function","doc":"Negative acknowledges of one or more messages.\n\nThis is a RabbitMQ specific extension to AMQP 0.9.1. It is equivalent to `reject/3`, but allows\nrejecting multiple messages using the `:multiple` option.","title":"AMQP.Basic.nack/3","ref":"AMQP.Basic.html#nack/3"},{"type":"function","doc":"* `:multiple` - If set, all messages up to the one specified by\n    `delivery_tag` are considered as not acknowledged by the server (default\n    `false`)\n\n  * `:requeue` - If set, the message will be returned to the queue and\n    redelivered to the next available consumer (default `true`)","title":"Options - AMQP.Basic.nack/3","ref":"AMQP.Basic.html#nack/3-options"},{"type":"function","doc":"Publishes a message to an Exchange.\n\nThis method publishes a message to a specific exchange. The message will be\nrouted to queues as defined by the exchange configuration and distributed to\nany subscribers.\n\nThe parameter `exchange` specifies the name of the exchange to publish to. If\nset to empty string, it publishes to the default exchange.\n\nThe `routing_key` parameter specifies the routing key for the message.\n\nThe `payload` parameter specifies the message content as a binary.\n\nIn addition to the previous parameters, the following options can be used:","title":"AMQP.Basic.publish/5","ref":"AMQP.Basic.html#publish/5"},{"type":"function","doc":"* `:mandatory` - If set, returns an error if the broker can't route the\n    message to a queue (default `false`)\n\n  * `:immediate` - If set, returns an error if the broker can't deliver the\n    message to a consumer immediately (default `false`)\n\n  * `:content_type` - MIME Content type\n\n  * `:content_encoding` - MIME Content encoding\n\n  * `:headers` - Message headers of type `t:AMQP.arguments/0`. Can be used\n    with headers Exchanges\n\n  * `:persistent` - If set, uses persistent delivery mode. Messages marked as\n    `persistent` that are delivered to `durable` queues will be logged to disk\n\n  * `:correlation_id` - application correlation identifier\n\n  * `:priority` - message priority, ranging from 0 to 9\n\n  * `:reply_to` - name of the reply queue\n\n  * `:expiration` - how long the message is valid (in milliseconds)\n\n  * `:message_id` - message identifier\n\n  * `:timestamp` - timestamp associated with this message (epoch time)\n\n  * `:type` - message type as a string\n\n  * `:user_id` - creating user ID. RabbitMQ will validate this against the\n    active connection user\n\n  * `:app_id` - publishing application ID","title":"Options - AMQP.Basic.publish/5","ref":"AMQP.Basic.html#publish/5-options"},{"type":"function","doc":"iex> AMQP.Basic.publish chan, \"my_exchange\", \"my_routing_key\", \"Hello World!\", persistent: true\n    :ok","title":"Examples - AMQP.Basic.publish/5","ref":"AMQP.Basic.html#publish/5-examples"},{"type":"function","doc":"Sets the message prefetch count or prefetch size (in bytes).\n\nThis allows you to limit the number of unacknowledged messages.","title":"AMQP.Basic.qos/2","ref":"AMQP.Basic.html#qos/2"},{"type":"function","doc":"* `:prefetch_size` - the prefetch size in bytes (default `0`)\n\n  * `:prefetch_count` - the prefetch count (default `0`)\n\n  * `:global` - If set, this applies to the entire Connection, otherwise\n    it applies only to the given Channel (default `false`)","title":"Options - AMQP.Basic.qos/2","ref":"AMQP.Basic.html#qos/2-options"},{"type":"function","doc":"Asks the server to redeliver all unacknowledged messages on a specified channel.","title":"AMQP.Basic.recover/2","ref":"AMQP.Basic.html#recover/2"},{"type":"function","doc":"* `:requeue` - If set, the server will attempt to requeue the message,\n    potentially delivering it to another subscriber. Otherwise it will be\n    redelivered to the original recipient (default `false`)","title":"Options - AMQP.Basic.recover/2","ref":"AMQP.Basic.html#recover/2-options"},{"type":"function","doc":"Rejects (and, optionally, requeues) a message.","title":"AMQP.Basic.reject/3","ref":"AMQP.Basic.html#reject/3"},{"type":"function","doc":"* `:requeue` - If set, the message is requeued by the server, otherwise\n    it's discarded (default `true`)","title":"Options - AMQP.Basic.reject/3","ref":"AMQP.Basic.html#reject/3-options"},{"type":"function","doc":"Registers a handler to deal with returned messages.\n\nThe registered process will receive `{:basic_return, payload, meta}` tuples.","title":"AMQP.Basic.return/2","ref":"AMQP.Basic.html#return/2"},{"type":"type","doc":"","title":"AMQP.Basic.consumer_tag/0","ref":"AMQP.Basic.html#t:consumer_tag/0"},{"type":"type","doc":"","title":"AMQP.Basic.delivery_tag/0","ref":"AMQP.Basic.html#t:delivery_tag/0"},{"type":"type","doc":"","title":"AMQP.Basic.error/0","ref":"AMQP.Basic.html#t:error/0"},{"type":"type","doc":"","title":"AMQP.Basic.exchange/0","ref":"AMQP.Basic.html#t:exchange/0"},{"type":"type","doc":"","title":"AMQP.Basic.payload/0","ref":"AMQP.Basic.html#t:payload/0"},{"type":"type","doc":"","title":"AMQP.Basic.queue/0","ref":"AMQP.Basic.html#t:queue/0"},{"type":"type","doc":"","title":"AMQP.Basic.routing_key/0","ref":"AMQP.Basic.html#t:routing_key/0"},{"type":"module","doc":"Functions to operate on Channels.","title":"AMQP.Channel","ref":"AMQP.Channel.html"},{"type":"function","doc":"Closes an open Channel.","title":"AMQP.Channel.close/1","ref":"AMQP.Channel.html#close/1"},{"type":"function","doc":"Opens a new Channel in a previously opened Connection.\n\nAllows optionally to pass a `t:custom_consumer/0` to start a custom consumer\nimplementation. The consumer must implement the `:amqp_gen_consumer` behavior\nfrom `:amqp_client`. See `:amqp_connection.open_channel/2` for more details\nand `AMQP.DirectConsumer` for an example of a custom consumer.","title":"AMQP.Channel.open/2","ref":"AMQP.Channel.html#open/2"},{"type":"type","doc":"","title":"AMQP.Channel.custom_consumer/0","ref":"AMQP.Channel.html#t:custom_consumer/0"},{"type":"type","doc":"","title":"AMQP.Channel.t/0","ref":"AMQP.Channel.html#t:t/0"},{"type":"module","doc":"Functions that work with publisher confirms (RabbitMQ extension to AMQP\n0.9.1).","title":"AMQP.Confirm","ref":"AMQP.Confirm.html"},{"type":"function","doc":"On channel with confirm activated, return the next message sequence number.\n\nTo use in combination with `register_handler/2`","title":"AMQP.Confirm.next_publish_seqno/1","ref":"AMQP.Confirm.html#next_publish_seqno/1"},{"type":"function","doc":"Register a handler for confirms on channel.\n\nThe handler will receive either:\n\n  * `{:basic_ack, seqno, multiple}`\n\n  * `{:basic_nack, seqno, multiple}`\n\nThe `seqno` (delivery_tag) is an integer, the sequence number of the message.\n\n`multiple` is a boolean, when `true` means multiple messages confirm, up to\n`seqno`.\n\nSee https://www.rabbitmq.com/confirms.html","title":"AMQP.Confirm.register_handler/2","ref":"AMQP.Confirm.html#register_handler/2"},{"type":"function","doc":"Activates publishing confirmations on the channel.","title":"AMQP.Confirm.select/1","ref":"AMQP.Confirm.html#select/1"},{"type":"function","doc":"Remove the return handler.\n\nIt does nothing if there is no such handler.","title":"AMQP.Confirm.unregister_handler/1","ref":"AMQP.Confirm.html#unregister_handler/1"},{"type":"function","doc":"Wait until all messages published since the last call have been either ack'd\nor nack'd by the broker.\n\nSame as `wait_for_confirms/2` but with the default timeout of 60 seconds.","title":"AMQP.Confirm.wait_for_confirms/1","ref":"AMQP.Confirm.html#wait_for_confirms/1"},{"type":"function","doc":"Wait until all messages published since the last call have been either ack'd\nor nack'd by the broker, or until timeout elapses.\n\nReturns `true` if all messages are ack'd. Returns `false` if *any* of the messages\nare nack'd. Returns `:timeout` on timeouts.\n\n`timeout` can be an integer or a tuple with the \"time unit\" (see the spec). If just an integer\nis provided, it's assumed to be *in seconds*. This is unconventional Elixir/Erlang API\n(since usually the convention is milliseconds), but we are forwarding to the underlying\nAMQP Erlang library here and it would be a breaking change for this library to default\nto milliseconds.","title":"AMQP.Confirm.wait_for_confirms/2","ref":"AMQP.Confirm.html#wait_for_confirms/2"},{"type":"function","doc":"Wait until all messages published since the last call have been either ack'd\nor nack'd by the broker, or until timeout elapses.\n\nIf any of the messages were nack'd, the calling process dies.\n\nSame as `wait_for_confirms_or_die/2` but with the default timeout of 60 seconds.","title":"AMQP.Confirm.wait_for_confirms_or_die/1","ref":"AMQP.Confirm.html#wait_for_confirms_or_die/1"},{"type":"function","doc":"","title":"AMQP.Confirm.wait_for_confirms_or_die/2","ref":"AMQP.Confirm.html#wait_for_confirms_or_die/2"},{"type":"module","doc":"Functions to operate on Connections.","title":"AMQP.Connection","ref":"AMQP.Connection.html"},{"type":"function","doc":"Closes an open Connection.","title":"AMQP.Connection.close/1","ref":"AMQP.Connection.html#close/1"},{"type":"function","doc":"Opens a new connection.\n\nBehaves like `open/2` but takes only either AMQP URI or options.","title":"AMQP.Connection.open/1","ref":"AMQP.Connection.html#open/1"},{"type":"function","doc":"iex> options = [host: \"localhost\", port: 5672, virtual_host: \"/\", username: \"guest\", password: \"guest\"]\n    iex> AMQP.Connection.open(options)\n    {:ok, %AMQP.Connection{}}\n\n    iex> AMQP.Connection.open(\"amqp://guest:guest@localhost\")\n    {:ok, %AMQP.Connection{}}","title":"Examples - AMQP.Connection.open/1","ref":"AMQP.Connection.html#open/1-examples"},{"type":"function","doc":"Opens an new Connection to an AMQP broker.\n\nThe connections created by this module are supervised under  amqp_client's\nsupervision tree.  Please note that connections do not get restarted\nautomatically by the supervision tree in case of a failure. If you need\nrobust connections and channels, use monitors on the returned connection PID.","title":"AMQP.Connection.open/2","ref":"AMQP.Connection.html#open/2"},{"type":"function","doc":"* `:username` - The name of a user registered with the broker (default\n    `\"guest\"`)\n\n  * `:password` - The password of user (default to `\"guest\"`)\n\n  * `:virtual_host` - The name of a virtual host in the broker (defaults\n    `\"/\"`)\n\n  * `:host` - The hostname of the broker (default `\"localhost\"`)\n\n  * `:port` - The port the broker is listening on (default `5672`)\n\n  * `:channel_max` - The channel_max handshake parameter (default `0`)\n\n  * `:frame_max` - The frame_max handshake parameter (defaults `0`)\n\n  * `:heartbeat` - The hearbeat interval in seconds (defaults `10`)\n\n  * `:connection_timeout` - The connection timeout in milliseconds (efaults\n    `50000`)\n\n  * `:ssl_options` - Enable SSL by setting the location to cert files\n    (default `:none`)\n\n  * `:client_properties` - A list of extra client properties to be sent to\n    the server (default `[]`)\n\n  * `:socket_options` - Extra socket options. These are appended to the\n    default options. See http://www.erlang.org/doc/man/inet.html#setopts-2 and\n    http://www.erlang.org/doc/man/gen_tcp.html#connect-4 for descriptions of\n    the available options\n\n  * `:auth_mechanisms` - A list of authentication of SASL authentication\n    mechanisms to use. See\n    https://www.rabbitmq.com/access-control.html#mechanisms and\n    https://github.com/rabbitmq/rabbitmq-auth-mechanism-ssl for descriptions of\n    the available options\n\n  * `:name` - A human-readable string that will be displayed in the\n    management UI. Connection names do not have to be unique and cannot be\n    used as connection identifiers (default `:undefined`)","title":"Options - AMQP.Connection.open/2","ref":"AMQP.Connection.html#open/2-options"},{"type":"function","doc":"iex> options = [host: \"localhost\", port: 5672, virtual_host: \"/\", username: \"guest\", password: \"guest\", name: \"my-conn\"]\n    iex> AMQP.Connection.open(options)\n    {:ok, %AMQP.Connection{}}\n\n    iex> AMQP.Connection.open(\"amqp://guest:guest@localhost\", port: 5673)\n    {:ok, %AMQP.Connection{}}","title":"Examples - AMQP.Connection.open/2","ref":"AMQP.Connection.html#open/2-examples"},{"type":"function","doc":"To enable SSL, supply the following in the `ssl_options` field:\n\n  * `:cacertfile` - Specifies the certificates of the root Certificate\n    Authorities that we wish to implicitly trust\n\n  * `:certfile` - The client's own certificate in PEM format\n\n  * `:keyfile` - The client's private key in PEM format\n\nHere is an example:\n\n    iex> AMQP.Connection.open(\n      port: 5671,\n      ssl_options: [\n        cacertfile: '/path/to/testca/cacert.pem',\n        certfile: '/path/to/client/cert.pem',\n        keyfile: '/path/to/client/key.pem',\n        # only necessary with intermediate CAs\n        # depth: 2,\n        verify: :verify_peer\n      ]\n    )","title":"Enabling SSL - AMQP.Connection.open/2","ref":"AMQP.Connection.html#open/2-enabling-ssl"},{"type":"function","doc":"RabbitMQ supports user-specified connection names since version 3.6.2.\n\nPreviously AMQP took a connection name as a separate parameter on `open/2`\nand `open/3` and it is still supported in this version.\n\n    iex> options = [host: \"localhost\", port: 5672, virtual_host: \"/\", username: \"guest\", password: \"guest\"]\n    iex> AMQP.Connection.open(options, :undefined)\n    {:ok, %AMQP.Connection{}}\n\n    iex> AMQP.Connection.open(\"amqp://guest:guest@localhost\", \"my-connection\")\n    {:ok, %AMQP.Connection{}}\n\n    iex> AMQP.Connection.open(\"amqp://guest:guest@localhost\", \"my-connection\", options)\n    {:ok, %AMQP.Connection{}}\n\nHowever the connection name parameter is now deprecated and might not be\nsupported in the future versions.\n\nYou are recommended to pass it with `:name` option instead:\n\n    iex> AMQP.Connection.open(\"amqp://guest:guest@localhost\", name: \"my-connection\")\n    {:ok, %AMQP.Connection{}}","title":"Backward compatibility for connection name - AMQP.Connection.open/2","ref":"AMQP.Connection.html#open/2-backward-compatibility-for-connection-name"},{"type":"type","doc":"","title":"AMQP.Connection.t/0","ref":"AMQP.Connection.html#t:t/0"},{"type":"module","doc":"`AMQP.DirectConsumer` is an example custom consumer. It's argument is a pid\nof a process which the channel is meant to forward the messages to.","title":"AMQP.DirectConsumer","ref":"AMQP.DirectConsumer.html"},{"type":"module","doc":"iex> AMQP.Channel.open(conn, {AMQP.DirectConsumer, self()})\n\nThis will forward all the messages from the channel to the calling process.\n\nThis is an Elixir reimplementation of `:amqp_direct_consumer`. (https://github.com/rabbitmq/rabbitmq-erlang-client/blob/master/src/amqp_direct_consumer.erl)\n\nFor more information see:\nhttps://www.rabbitmq.com/erlang-client-user-guide.html#consumers-imlementation","title":"Usage - AMQP.DirectConsumer","ref":"AMQP.DirectConsumer.html#module-usage"},{"type":"module","doc":"","title":"Caveat - AMQP.DirectConsumer","ref":"AMQP.DirectConsumer.html#module-caveat"},{"type":"module","doc":"AMQP 2.0 comes with an improved version of the default consumer(`AMQP.SelectiveConsumer`).\nThere is not an obvious reason using DirectConsumer after the version 2.0.\nWe highly recommend you to use the default consumer which lets you decouple\nthe consumer concern from the channel.\nIf you still want to keep using `DirectConsumer`, keep reading the caveat below.","title":"You are recommended to use the default consumer - AMQP.DirectConsumer","ref":"AMQP.DirectConsumer.html#module-you-are-recommended-to-use-the-default-consumer"},{"type":"module","doc":"By default, the DirectConsumer detects the user consumer down then...\n\n* DirectConsumer returns :error in handle_info which results the process to exit.\n* The channel supervisor will detect the DirectConsumer shutdown but the\n  restart will be failing as the user consumer is still down.\n* It ends up the channel process to shut down.\n\nHowever this is an abnormal shutdown and can cause an unintended race condition.\n\nTo avoid it, make sure to close the channel explicitly and shut down your\nconsumer with a `:normal` signal.","title":"Close the channel explicitly - AMQP.DirectConsumer","ref":"AMQP.DirectConsumer.html#module-close-the-channel-explicitly"},{"type":"module","doc":"DirectConsumer follows the Erlang version and ignores only `:normal` signals\nfor the user consumer exit.\n\nYou might want to also ignore `:shutdown` signals as it can also be called\nbefore the channel is closed.\n\nYou can set the additional reasons to ignore with the following options:\n\n    iex> opts = [ignore_consumer_down: [:normal, :shutdown]]\n    iex> AMQP.Channel.open(conn, {AMQP.DirectConsumer, {self(), opts}})\n\nYou can also ignore the user consumer down completely by setting `true` to the value:\n\n    iex> opts = [ignore_consumer_down: true]\n    iex> AMQP.Channel.open(conn, {AMQP.DirectConsumer, {self(), opts}})","title":"Ignore the user consumer shutdown - AMQP.DirectConsumer","ref":"AMQP.DirectConsumer.html#module-ignore-the-user-consumer-shutdown"},{"type":"module","doc":"Functions to operate on Exchanges.","title":"AMQP.Exchange","ref":"AMQP.Exchange.html"},{"type":"function","doc":"Binds an Exchange to another Exchange using the exchange.bind AMQP method (a\nRabbitMQ-specific extension).","title":"AMQP.Exchange.bind/4","ref":"AMQP.Exchange.html#bind/4"},{"type":"function","doc":"* `:routing_key` - the routing key to use for the binding (default `\"\"`)\n\n  * `:nowait` - If set, the bind operation is asynchronous (default `false`)\n\n  * `:arguments` - A list of arguments to pass when binding (of type\n    `t:AMQP.arguments/0`). See the [README](readme.html) for more information\n    (default to `[]`)","title":"Options - AMQP.Exchange.bind/4","ref":"AMQP.Exchange.html#bind/4-options"},{"type":"function","doc":"Declares an Exchange. The default Exchange type is `direct`.\n\nAMQP 0-9-1 brokers provide four pre-declared exchanges:\n\n  * `:direct` exchange: (empty string) or `amq.direct`\n\n  * `:fanout` exchange: `amq.fanout`\n\n  * `:topic` exchange: `amq.topic`\n\n  * `:headers` exchange: `amq.match` (and `amq.headers` in RabbitMQ)\n\nBesides the exchange name and type, the following options can be used:","title":"AMQP.Exchange.declare/4","ref":"AMQP.Exchange.html#declare/4"},{"type":"function","doc":"* `:durable` - If set, keeps the Exchange between restarts of the broker\n\n  * `:auto_delete` - If set, deletes the Exchange once all queues unbind from\n    it\n\n  * `:passive` - If set, returns an error if the Exchange does not already\n    exist\n\n  * `:internal` - If set, the exchange may not be used directly by\n    publishers, but only when bound to other exchanges. Internal exchanges are\n    used to construct wiring that is not visible to applications\n\n  * `:nowait` - If set, the declare operation is asynchronous (default `false`)\n\n  * `:arguments` - A list of arguments to pass when declaring (of type\n    `t:AMQP.arguments/0`).  See the [README](readme.html) for more information\n    (default to `[]`)","title":"Options - AMQP.Exchange.declare/4","ref":"AMQP.Exchange.html#declare/4-options"},{"type":"function","doc":"Deletes an Exchange by name. When an Exchange is deleted all bindings to it are\nalso deleted.","title":"AMQP.Exchange.delete/3","ref":"AMQP.Exchange.html#delete/3"},{"type":"function","doc":"* `:if_unused` - If set, the server will only delete the exchange if it has\n    no queue bindings\n\n  * `:nowait` - If set, the delete operation is asynchronous (default\n    `false`)","title":"Options - AMQP.Exchange.delete/3","ref":"AMQP.Exchange.html#delete/3-options"},{"type":"function","doc":"Convenience function to declare an Exchange of type `direct`.","title":"AMQP.Exchange.direct/3","ref":"AMQP.Exchange.html#direct/3"},{"type":"function","doc":"This function takes the same options as `declare/4`.","title":"Options - AMQP.Exchange.direct/3","ref":"AMQP.Exchange.html#direct/3-options"},{"type":"function","doc":"Convenience function to declare an Exchange of type `fanout`.","title":"AMQP.Exchange.fanout/3","ref":"AMQP.Exchange.html#fanout/3"},{"type":"function","doc":"This function takes the same options as `declare/4`.","title":"Options - AMQP.Exchange.fanout/3","ref":"AMQP.Exchange.html#fanout/3-options"},{"type":"function","doc":"Convenience function to declare an Exchange of type `topic`.","title":"AMQP.Exchange.topic/3","ref":"AMQP.Exchange.html#topic/3"},{"type":"function","doc":"This function takes the same options as `declare/4`.","title":"Options - AMQP.Exchange.topic/3","ref":"AMQP.Exchange.html#topic/3-options"},{"type":"function","doc":"Unbinds an Exchange from another Exchange or a Queue using the\nexchange.unbind AMQP method (a RabbitMQ-specific extension).","title":"AMQP.Exchange.unbind/4","ref":"AMQP.Exchange.html#unbind/4"},{"type":"function","doc":"* `:routing_key` - the routing key to use for the binding (default `\"\"`)\n\n  * `:nowait` - If set, the declare operation is asynchronous (default `false`)\n\n  * `:arguments` - A list of arguments to pass when declaring (of type\n    `t:AMQP.arguments/0`). See the README for more information (defaults `[]`)","title":"Options - AMQP.Exchange.unbind/4","ref":"AMQP.Exchange.html#unbind/4-options"},{"type":"module","doc":"Functions to operate on Queues.","title":"AMQP.Queue","ref":"AMQP.Queue.html"},{"type":"function","doc":"Binds a Queue to an Exchange.","title":"AMQP.Queue.bind/4","ref":"AMQP.Queue.html#bind/4"},{"type":"function","doc":"* `:routing_key` - The routing key used to bind the queue to the exchange\n    (default `\"\"`)\n\n  * `:nowait` - If `true`, the binding is not synchronous (default `false`)\n\n  * `:arguments` - A list of arguments to pass when binding (of type\n    `t:AMQP.arguments/0`).  See the [README](readme.html) for more information\n    (default `[]`)","title":"Options - AMQP.Queue.bind/4","ref":"AMQP.Queue.html#bind/4-options"},{"type":"function","doc":"Returns a number of active consumers on the queue.","title":"AMQP.Queue.consumer_count/2","ref":"AMQP.Queue.html#consumer_count/2"},{"type":"function","doc":"Declares a queue. The optional `queue` parameter is used to set the name.\nIf set to an empty string (default), the server will assign a name.\n\nBesides the queue name, the following options can be used:","title":"AMQP.Queue.declare/3","ref":"AMQP.Queue.html#declare/3"},{"type":"function","doc":"* `:durable` - If set, keeps the Queue between restarts of the broker\n    (default `false`)\n\n  * `:auto_delete` - If set, deletes the Queue once all subscribers\n    disconnect (default to `false`)\n\n  * `:exclusive` - If set, only one subscriber can consume from the Queue\n    (default `false`)\n\n  * `:passive` - If set, raises an error unless the queue already exists\n    (default `false`)\n\n  * `:nowait` - If set, the declare operation is asynchronous (default\n    `false`)\n\n  * `:arguments` - A list of arguments to pass when declaring (of type\n    `t:AMQP.arguments/0`). See the [README](readme.html) for more information\n    (default `[]`)","title":"Options - AMQP.Queue.declare/3","ref":"AMQP.Queue.html#declare/3-options"},{"type":"function","doc":"Deletes a Queue by name.","title":"AMQP.Queue.delete/3","ref":"AMQP.Queue.html#delete/3"},{"type":"function","doc":"* `:if_unused` - If set, the server will only delete the queue if it has no\n    consumers. If the queue has consumers, it's not deleted and an error is\n    returned\n\n  * `:if_empty` - If set, the server will only delete the queue if it has no\n    messages\n\n  * `:nowait` - If set, the delete operation is asynchronous","title":"Options - AMQP.Queue.delete/3","ref":"AMQP.Queue.html#delete/3-options"},{"type":"function","doc":"Returns true if queue is empty (has no messages ready), false otherwise.","title":"AMQP.Queue.empty?/2","ref":"AMQP.Queue.html#empty?/2"},{"type":"function","doc":"Returns the number of messages that are ready for delivery (e.g. not pending\nacknowledgements) in the queue.","title":"AMQP.Queue.message_count/2","ref":"AMQP.Queue.html#message_count/2"},{"type":"function","doc":"Discards all messages in the Queue.","title":"AMQP.Queue.purge/2","ref":"AMQP.Queue.html#purge/2"},{"type":"function","doc":"Returns the message count and consumer count for the given queue.\nUses `declare/3` with the `:passive` option set.","title":"AMQP.Queue.status/2","ref":"AMQP.Queue.html#status/2"},{"type":"function","doc":"Convenience to consume messages from a Queue.\n\nThe handler function must have arity 2 and will receive as arguments a binary\nwith the message payload and a Map with the message properties.\n\nThe consumed message will be acknowledged after executing the handler function.\n\nIf an exception is raised by the handler function, the message is rejected.\n\nThis convenience function will spawn a process and register it using\n`AMQP.Basic.consume/4`.","title":"AMQP.Queue.subscribe/4","ref":"AMQP.Queue.html#subscribe/4"},{"type":"function","doc":"Unbinds a Queue from an Exchange.","title":"AMQP.Queue.unbind/4","ref":"AMQP.Queue.html#unbind/4"},{"type":"function","doc":"* `:routing_key` - The routing queue for removing the binding (default `\"\"`)\n\n  * `:arguments` - A list of arguments to pass when unbinding (of type\n    `t:AMQP.arguments/0`).  See the [README](readme.html) for more information\n    (defaults `[]`)","title":"Options - AMQP.Queue.unbind/4","ref":"AMQP.Queue.html#unbind/4-options"},{"type":"function","doc":"Stops the consumer identified by `consumer_tag` from consuming.\n\nInternally just calls `AMQP.Basic.cancel/2`.","title":"AMQP.Queue.unsubscribe/2","ref":"AMQP.Queue.html#unsubscribe/2"},{"type":"module","doc":"This is an Elixir reimplementation of `:amqp_selective_consumer` -\n[source](https://github.com/rabbitmq/rabbitmq-server/blob/master/deps/amqp_client/src/amqp_selective_consumer.erl).\n\nThe module is used by default when you open a channel via\n`AMQP.Channel.open/2` and allows you to end consumer processes via\n`AMQP.Basic.consume/4` and receive messages from a queue.\n\nUsually you don't have to pay attention to this module as the interaction\nwould be made through `AMQP.Channel.open/2`, `AMQP.Basic.consume/4`,\n`AMQP.Basic.return/2`, `AMQP.Confirm.register_handler/2` etc.","title":"AMQP.SelectiveConsumer","ref":"AMQP.SelectiveConsumer.html"},{"type":"function","doc":"Ported from `:amqp_selective_consumer.register_default_consumer/2`.\n\nThis function registers a default consumer with the channel.\n\nA default consumer is used when a subscription is made via\n`amqp_channel:call(ChannelPid, #'basic.consume'{})` (rather than\n`{@module}:subscribe/3`) and hence there is no consumer pid registered with\nthe consumer tag. In this case, the relevant deliveries will be sent to the\ndefault consumer.","title":"AMQP.SelectiveConsumer.register_default_consumer/2","ref":"AMQP.SelectiveConsumer.html#register_default_consumer/2"},{"type":"type","doc":"","title":"AMQP.SelectiveConsumer.t/0","ref":"AMQP.SelectiveConsumer.html#t:t/0"},{"type":"exception","doc":"Raised when the connection is closed or blocked.","title":"AMQP.BasicError","ref":"AMQP.BasicError.html"},{"type":"extras","doc":"# AMQP\n\n[![Build Status](https://github.com/pma/amqp/workflows/Elixir%20CI/badge.svg?branch=main)](https://github.com/pma/amqp/actions?query=workflow%3A%22Elixir+CI%22+branch%3Amain)\n[![Module Version](https://img.shields.io/hexpm/v/amqp.svg)](https://hex.pm/packages/amqp)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/amqp/)\n[![Total Download](https://img.shields.io/hexpm/dt/amqp.svg)](https://hex.pm/packages/amqp)\n[![Last Updated](https://img.shields.io/github/last-commit/pma/amqp.svg)](https://github.com/pma/amqp/commits/main)\n[![License](https://img.shields.io/hexpm/l/amqp.svg)](https://github.com/pma/amqp/blob/main/LICENSE)\n\nSimple Elixir wrapper for the Erlang RabbitMQ client.\n\nThe API is based on Langohr, a Clojure client for RabbitMQ.","title":"AMQP","ref":"readme.html"},{"type":"extras","doc":"To upgrade from the old version, please read our upgrade guides:\n\n* [0.x to 1.x](https://github.com/pma/amqp/wiki/Upgrade-from-0.X-to-1.0)\n* [1.x to 2.x](https://github.com/pma/amqp/wiki/2.0-Release-Notes#breaking-changes-and-upgrade-guide)\n* [2.x to 3.x](https://github.com/pma/amqp/wiki/3.0-Release-Notes#breaking-changes-and-upgrade-guide)\n* [3.X to 4.x](https://github.com/pma/amqp/wiki/4.0-Release-Notes)","title":"Upgrading guides - AMQP","ref":"readme.html#upgrading-guides"},{"type":"extras","doc":"Also, note that [the RabbitMQ team has reported some performance regressions with OTP 27](https://www.rabbitmq.com/blog/2024/05/23/erlang27-support).","title":"OTP 27 support - AMQP","ref":"readme.html#otp-27-support"},{"type":"extras","doc":"Add AMQP as a dependency in your `mix.exs` file.\n\n```elixir\ndef deps do\n  [\n    {:amqp, \"~> 4.0\"}\n  ]\nend\n```\n\nElixir will start `amqp` automatically with this if you use Elixir 1.6+.\n\nIf that's not the case (use `Application.started_applications/0` to check), try\nadding `:amqp` to `applications` or `extra_applications` in your `mix.exs`. Or\ncall `Application.ensure_started(:amqp)` at the start.\n\nAfter you are done, run `mix deps.get` in your shell to fetch and compile AMQP.\nStart an interactive Elixir shell with `iex -S mix`.\n\n```elixir\niex> {:ok, conn} = AMQP.Connection.open()\n# {:ok, %AMQP.Connection{pid: #PID<0.165.0>}}\n\niex> {:ok, chan} = AMQP.Channel.open(conn)\n# {:ok, %AMQP.Channel{conn: %AMQP.Connection{pid: #PID<0.165.0>}, pid: #PID<0.177.0>}\n\niex> AMQP.Queue.declare(chan, \"test_queue\")\n# {:ok, %{consumer_count: 0, message_count: 0, queue: \"test_queue\"}}\n\niex> AMQP.Exchange.declare(chan, \"test_exchange\")\n# :ok\n\niex> AMQP.Queue.bind(chan, \"test_queue\", \"test_exchange\")\n# :ok\n\niex> AMQP.Basic.publish(chan, \"test_exchange\", \"\", \"Hello, World!\")\n# :ok\n\niex> {:ok, payload, meta} = AMQP.Basic.get(chan, \"test_queue\")\niex> payload\n# \"Hello, World!\"\n\niex> AMQP.Queue.subscribe(chan, \"test_queue\", fn payload, _meta -> IO.puts(\"Received: #{payload}\") end)\n# {:ok, \"amq.ctag-5L8U-n0HU5doEsNTQpaXWg\"}\n\niex> AMQP.Basic.publish(chan, \"test_exchange\", \"\", \"Hello, World!\")\n# :ok\n# Received: Hello, World!\n```","title":"Usage - AMQP","ref":"readme.html#usage"},{"type":"extras","doc":"```elixir\ndefmodule Consumer do\n  use GenServer\n  use AMQP\n\n  def start_link do\n    GenServer.start_link(__MODULE__, [], [])\n  end\n\n  @exchange    \"gen_server_test_exchange\"\n  @queue       \"gen_server_test_queue\"\n  @queue_error \"#{@queue}_error\"\n\n  def init(_opts) do\n    {:ok, conn} = Connection.open(\"amqp://guest:guest@localhost\")\n    {:ok, chan} = Channel.open(conn)\n    setup_queue(chan)\n\n    # Limit unacknowledged messages to 10\n    :ok = Basic.qos(chan, prefetch_count: 10)\n    # Register the GenServer process as a consumer\n    {:ok, _consumer_tag} = Basic.consume(chan, @queue)\n    {:ok, chan}\n  end\n\n  # Confirmation sent by the broker after registering this process as a consumer\n  def handle_info({:basic_consume_ok, %{consumer_tag: consumer_tag}}, chan) do\n    {:noreply, chan}\n  end\n\n  # Sent by the broker when the consumer is unexpectedly cancelled (such as after a queue deletion)\n  def handle_info({:basic_cancel, %{consumer_tag: consumer_tag}}, chan) do\n    {:stop, :normal, chan}\n  end\n\n  # Confirmation sent by the broker to the consumer process after a Basic.cancel\n  def handle_info({:basic_cancel_ok, %{consumer_tag: consumer_tag}}, chan) do\n    {:noreply, chan}\n  end\n\n  def handle_info({:basic_deliver, payload, %{delivery_tag: tag, redelivered: redelivered}}, chan) do\n    # You might want to run payload consumption in separate Tasks in production\n    consume(chan, tag, redelivered, payload)\n    {:noreply, chan}\n  end\n\n  defp setup_queue(chan) do\n    {:ok, _} = Queue.declare(chan, @queue_error, durable: true)\n    # Messages that cannot be delivered to any consumer in the main queue will be routed to the error queue\n    {:ok, _} = Queue.declare(chan, @queue,\n                             durable: true,\n                             arguments: [\n                               {\"x-dead-letter-exchange\", :longstr, \"\"},\n                               {\"x-dead-letter-routing-key\", :longstr, @queue_error}\n                             ]\n                            )\n    :ok = Exchange.fanout(chan, @exchange, durable: true)\n    :ok = Queue.bind(chan, @queue, @exchange)\n  end\n\n  defp consume(channel, tag, redelivered, payload) do\n    number = String.to_integer(payload)\n    if number <= 10 do\n      :ok = Basic.ack channel, tag\n      IO.puts \"Consumed a #{number}.\"\n    else\n      :ok = Basic.reject channel, tag, requeue: false\n      IO.puts \"#{number} is too big and was rejected.\"\n    end\n\n  rescue\n    # Requeue unless it's a redelivered message.\n    # This means we will retry consuming a message once in case of exception\n    # before we give up and have it moved to the error queue\n    #\n    # You might also want to catch :exit signal in production code.\n    # Make sure you call ack, nack or reject otherwise consumer will stop\n    # receiving messages.\n    exception ->\n      :ok = Basic.reject channel, tag, requeue: not redelivered\n      IO.puts \"Error converting #{payload} to integer\"\n  end\nend\n```\n\n```iex\niex> Consumer.start_link\n{:ok, #PID<0.261.0>}\niex> {:ok, conn} = AMQP.Connection.open\n{:ok, %AMQP.Connection{pid: #PID<0.165.0>}}\niex> {:ok, chan} = AMQP.Channel.open(conn)\n{:ok, %AMQP.Channel{conn: %AMQP.Connection{pid: #PID<0.165.0>}, pid: #PID<0.177.0>}\niex> AMQP.Basic.publish chan, \"gen_server_test_exchange\", \"\", \"5\"\n:ok\nConsumed a 5.\niex> AMQP.Basic.publish chan, \"gen_server_test_exchange\", \"\", \"42\"\n:ok\n42 is too big and was rejected.\niex> AMQP.Basic.publish chan, \"gen_server_test_exchange\", \"\", \"Hello, World!\"\n:ok\nError converting Hello, World! to integer\nError converting Hello, World! to integer\n```","title":"Setup a consumer GenServer - AMQP","ref":"readme.html#setup-a-consumer-genserver"},{"type":"extras","doc":"#### Connections and channels\n\nYou can define a connection and channel in your config and AMQP will\nautomatically...\n\n* Open the connection and channel at the start of the application\n* Automatically try to reconnect if they are disconnected\n\n```elixir\nconfig :amqp,\n  connections: [\n    myconn: [url: \"amqp://guest:guest@myhost:12345\"],\n  ],\n  channels: [\n    mychan: [connection: :myconn]\n  ]\n```\n\nYou can access the connection/channel via `AMQP.Application`.\n\n```elixir\niex> {:ok, chan} = AMQP.Application.get_channel(:mychan)\niex> :ok = AMQP.Basic.publish(chan, \"\", \"\", \"Hello\")\n```\n\nWhen a channel is down and reconnected, you have to make sure your consumer\nsubscribes to a channel again.\n\nSee the documentation for `AMQP.Application.get_connection/1` and\n`AMQP.Application.get_channel/1` for more details.","title":"Configuration - AMQP","ref":"readme.html#configuration"},{"type":"extras","doc":"The parameter `arguments` in `Queue.declare`, `Exchange.declare`,\n`Basic.consume` and the parameter `headers` in `Basic.publish` are a list of\ntuples in the form `{name, type, value}`, where `name` is a binary containing\nthe argument/header name, `type` is an atom describing the AMQP field type and\n`value` a term compatible with the AMQP field type.\n\nThe valid AMQP field types are:\n\n`:longstr` | `:signedint` | `:decimal` | `:timestamp` | `:table` | `:byte` | `:double` | `:float` | `:long` | `:short` | `:bool` | `:binary` | `:void` | `:array`\n\nValid argument names in `Queue.declare` include:\n\n* \"x-expires\"\n* \"x-message-ttl\"\n* \"x-dead-letter-routing-key\"\n* \"x-dead-letter-exchange\"\n* \"x-max-length\"\n* \"x-max-length-bytes\"\n\nValid argument names in `Basic.consume` include:\n\n* \"x-priority\"\n* \"x-cancel-on-ha-failover\"\n\nValid argument names in `Exchange.declare` include:\n\n* \"alternate-exchange\"","title":"Types of arguments and headers - AMQP","ref":"readme.html#types-of-arguments-and-headers"},{"type":"extras","doc":"#### Is amqp 4.x compatible with RabbitMQ 3.x?\n\nYes, it is.\n\nThis library uses [the official Erlang RabbitMQ client](https://hex.pm/packages/amqp_client) under the hood.\nAs long as the client works with the old RabbitMQ version, our library will also support the old version.\n\nHere is [the comment](https://github.com/rabbitmq/rabbitmq-server/issues/12510#issuecomment-2442175567) from the RabbitMQ team.\n\n#### Does the library support AMQP 1.0?\n\nNo, it doesn't. This library supports only AMQP 0.9.1 and we have no plan to support 1.0 at this moment.\n\nRabbitMQ 4 now officially supports AMQP 1.0 along with 0.9.1. You might get some good benefits from using the protocol.\n\n- https://www.rabbitmq.com/blog/2024/08/05/native-amqp\n- https://www.rabbitmq.com/blog/2024/08/21/amqp-benchmarks\n- https://www.rabbitmq.com/blog/2024/09/02/amqp-flow-control\n\nSince AMQP 1.0 protocol design is significantly different from 0.9.1, we also think it is a good idea to start from scratch instead of building on top of this library. \n\n\n#### Consumer stops receiving messages\n\nIt usually happens when your code doesn't send an acknowledgement(ack, nack or\nreject) after receiving a message.\n\nIf you use GenServer for your consumer, try storing the number of messages the server is currently processing to the GenServer state.\n\nIf the number equals `prefetch_count`, those messages were left without\nacknowledgements and that's why the consumer has stopped receiving more\nmessages.\n\nAlso, review the following points:\n\n- when an exception was raised how it would be handled\n- when :exit signal was thrown how it would be handled\n- when a message processing took long time what could happen\n\nAlso, make sure that the consumer monitors the channel pid. When the channel is\ngone, you have to reopen it and subscribe to a new channel again.\n\n#### The version compatibility\n\nCheck out [this article](https://github.com/pma/amqp/wiki/Versions-and-Compatibilities) to find out the compatibility with Elixir, OTP and RabbitMQ.\n\n#### Heartbeats\n\nIf the connection is dropped automatically, consider enabling heartbeats.\n\nYou can set the `heartbeat` option when you open a connection.\n\nFor more details, read [this article](http://www.rabbitmq.com/heartbeats.html#tcp-proxies)","title":"Troubleshooting / FAQ - AMQP","ref":"readme.html#troubleshooting-faq"},{"type":"extras","doc":"Copyright (c) 2014 Paulo Almeida\n\nThis library is MIT licensed. See the\n[LICENSE](https://github.com/pma/amqp/blob/main/LICENSE) for details.","title":"Copyright and License - AMQP","ref":"readme.html#copyright-and-license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}